@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import getpass
 import logging
 import os
 import posixpath
@@ -24,6 +24,7 @@ except ImportError:
     from StringIO import StringIO
 
 from mrjob.conf import combine_dicts, combine_paths
+from mrjob.parse import HADOOP_STREAMING_JAR_RE
 from mrjob.runner import MRJobRunner
 from mrjob.util import cmd_line
 
@@ -31,8 +32,6 @@ log = logging.getLogger('mrjob.hadoop')
 
 HDFS_URI_RE = re.compile(r'^hdfs://(.*?)(/.*?)$')
 
-HADOOP_STREAMING_JAR_RE = re.compile(r'^hadoop.*streaming.*\.jar$')
-
 # to filter out the log4j stuff that hadoop streaming prints out
 HADOOP_STREAMING_OUTPUT_RE = re.compile(r'^(\S+ \S+ \S+ \S+: )?(.*)$')
 
@@ -62,11 +61,11 @@ def fully_qualify_hdfs_path(path):
     elif path.startswith('/'):
         return 'hdfs://' + path
     else:
-        return 'hdfs:///user/%s/%s' % (os.environ['USER'], path)
+        return 'hdfs:///user/%s/%s' % (getpass.getuser(), path)
 
 class HadoopJobRunner(MRJobRunner):
     """Runs an :py:class:`~mrjob.job.MRJob` on your Hadoop cluster.
-    
+
     Input and support files can be either local or on HDFS; use ``hdfs://...``
     URLs to refer to files on HDFS.
 
@@ -74,7 +73,7 @@ class HadoopJobRunner(MRJobRunner):
     :py:meth:`~HadoopJobRunner.__init__` for details).
     """
     alias = 'hadoop'
-    
+
     def __init__(self, **kwargs):
         """:py:class:`HadoopJobRunner` takes the same arguments as
         :py:class:`~mrjob.runner.MRJobRunner`, plus some additional options
@@ -89,11 +88,11 @@ class HadoopJobRunner(MRJobRunner):
         :type hadoop_bin: str
         :param hadoop_bin: name/path of your hadoop program. Defaults to *hadoop_home* plus ``bin/hadoop``
         :type hadoop_home: str
-        :param hadoop_home: alternative to setting :envvar:`$HADOOP_HOME` variable.
+        :param hadoop_home: alternative to setting :envvar:`HADOOP_HOME` variable.
         :type hdfs_scratch_dir: str
         :param hdfs_scratch_dir: temp directory on HDFS. Default is ``tmp/mrjob``
         :type hadoop_streaming_jar: str
-        :param hadoop_streaming_jar: path to your hadoop streaming jar. If not set, we'll search for it inside :envvar:`$HADOOP_HOME`
+        :param hadoop_streaming_jar: path to your hadoop streaming jar. If not set, we'll search for it inside :envvar:`HADOOP_HOME`
         """
         super(HadoopJobRunner, self).__init__(**kwargs)
 
@@ -172,7 +171,7 @@ class HadoopJobRunner(MRJobRunner):
 
     def _setup_input(self):
         """Copy local input files (if any) to a special directory on HDFS.
-        
+
         Set self._hdfs_input_files
         """
         # winnow out HDFS files from local ones
@@ -199,11 +198,11 @@ class HadoopJobRunner(MRJobRunner):
             for i, path in enumerate(local_input_files):
                 if path == '-':
                     path = self._dump_stdin_to_local_file()
-                
+
                 target = '%s/%05i-%s' % (
                     hdfs_input_dir, i, os.path.basename(path))
                 self._upload_to_hdfs(path, target)
-            
+
             self._hdfs_input_files.append(hdfs_input_dir)
 
     def _pick_hdfs_uris_for_files(self):
@@ -230,7 +229,7 @@ class HadoopJobRunner(MRJobRunner):
             # don't bother with files already in HDFS
             if HDFS_URI_RE.match(path):
                 continue
-            
+
             self._upload_to_hdfs(path, file_dict['hdfs_uri'])
 
     def _mkdir_on_hdfs(self, path):
@@ -253,7 +252,7 @@ class HadoopJobRunner(MRJobRunner):
             stdin_file.write(line)
 
         return stdin_path
-                
+
     def _run_job_in_hadoop(self):
         # figure out local names for our files
         self._name_files()
@@ -348,12 +347,12 @@ class HadoopJobRunner(MRJobRunner):
         return args
 
     def _mapper_args(self, step_num):
-        return (self._script_args() + 
+        return (self._script_args() +
                 ['--step-num=%d' % step_num, '--mapper'] +
                 self._mr_job_extra_args())
 
     def _reducer_args(self, step_num):
-        return (self._script_args() + 
+        return (self._script_args() +
                 ['--step-num=%d' % step_num, '--reducer'] +
                 self._mr_job_extra_args())
 
@@ -477,14 +476,14 @@ class HadoopJobRunner(MRJobRunner):
 
     def ls(self, path_glob):
         hdfs_match = HDFS_URI_RE.match(path_glob)
-        
+
         if not hdfs_match:
             for path in super(HadoopJobRunner, self).ls(path_glob):
                 yield path
             return
 
         hdfs_prefix = hdfs_match.group(1)
-        
+
         stdout = self._invoke_hadoop(
             ['fs', '-lsr', path_glob],
             return_stdout=True,
@@ -548,7 +547,7 @@ class HadoopJobRunner(MRJobRunner):
 
         self._invoke_hadoop(['fs', '-touchz', dest])
 
-            
-        
-        
-    
+
+
+
+
